## Changelog

> **Warning**: This release has a known issue: #8351. Upgrade directly to
> v0.26.0 which includes a fix

### Features

- The `coder stat` fetches workspace utilization metrics, even from within a
  container. Our example templates have been updated to use this to show CPU,
  memory, disk via
  [agent metadata](https://coder.com/docs/v2/latest/templates/agent-metadata)
  (#8005)
- Helm: `coder.command` can specify a different command for the Coder pod
  (#8116)
- Enterprise deployments can create templates without 'everyone' group access
  (#7982)
  ![Disable "everyone"](https://github.com/coder/coder/assets/22407953/1c31cb9b-be5c-4bef-abee-324856734215)
- Add login type 'none' to prevent password login. This can come in handy for
  machine accounts for CI/CD pipelines or other automation (#8009)
- Healthcheck endpoint has a database section: `/api/v2/debug/health`
- Force DERP connections in CLI with `--disable-direct` flag (#8131)
- Disable all direct connections for a Coder deployment with
  [--block-direct-connections](https://coder.com/docs/v2/latest/cli/server#--block-direct-connections)
  (#7936)
- Search for workspaces based on last activity (#2658)
  ```text
  last_seen_before:"2023-01-14T23:59:59Z" last_seen_after:"2023-01-08T00:00:00Z"
  ```
- Queue position of pending workspace builds are shown in the dashboard (#8244)
  <img width="1449" alt="Queue position" src="https://github.com/coder/coder/assets/22407953/44515a19-ddfb-4431-8c2a-203487c4efe8">
- Enable Terraform debug mode via deployment configuration (#8260)
- Add github device flow for authentication (#8232)
- Sort Coder parameters with
  [display_order](https://registry.terraform.io/providers/coder/coder/latest/docs/data-sources/parameter)
  property (#8227)
- Users can convert from username/password accounts to OIDC accounts in Account
  settings (#8105) (@Emyrk)
  ![Convert account](https://github.com/coder/coder/assets/22407953/6ea28c1c-53d7-4eb5-8113-9a066739820c)
- Show service banner in SSH/TTY sessions (#8186)
- Helm chart now supports RBAC for deployments (#8233)

### Bug fixes

- `coder logout` will not invalidate long-lived API tokens (#8275)
- Helm: use `/healthz` for liveness and readiness probes instead of
  `/api/v2/buildinfo` (#8035)
- Close output writer before reader on Windows to unblock close (#8299)
- Resize terminal when dismissing warning (#8028)
- Fix footer year (#8036)
- Prevent filter input update when focused (#8102)
- Fix filters errors display (#8103)
- Show error when parameter is invalid (#8125)
- Display correct user_limit on license ui (#8118)
- Only collect prometheus database metrics when explicitly enabled (#8045)
- Avoid missed logs when streaming startup logs (#8029)
- Show git provider id instead of type (#8075)
- Disable websocket compression for startup logs in Safari (#8087)
- Revert to canvas renderer for xterm (#8138)

### Documentation

- Template inheritance with Terraform modules (#8328) (@bpmct)
- Steps for configuring trusted headers & origins in Helm chart (#8031)
- OIDC keycloak docs (#8042)
- Steps for registering a github app with coder (#7976)
- Prometheus scrape_config example (#8113)
- `coder ping` example for troubleshooting (#8133)
- Application logs (#8166)
- Strip CORS headers from applications (#8057)
- Max lifetime docs and refactor UI helper text (#8185)
- Add default dir for VS Code Desktop (#8184)
- Agent metadata is now GA (#8111) (@bpmct)
- Note SSH key location in workspaces (#8264)
- Update examples of IDEs: remove JetBrains Projector and add VS Code Server
  (#8310)

Compare:
[`v0.24.1...v0.25.0`](https://github.com/coder/coder/compare/v0.24.1...v0.25.0)

## Container image

- `docker pull ghcr.io/coder/coder:v0.25.0`

## Install/upgrade

Refer to our docs to [install](https://coder.com/docs/v2/latest/install) or
[upgrade](https://coder.com/docs/v2/latest/admin/upgrade) Coder, or use a
release asset below.
